flutter_scratch_card library

Classes

ScratchCard
A customizable scratch card widget.
ScratchController
Controller for the ScratchCard widget.
ScratchPoint
Represents a single scratch point or a line segment.
ScratchUtils
Utility class for haptic feedback and other helper functions.

Enums

ScratchAnimationType
Animation types supported by the scratch card's background layer.