ScratchPoint class

Represents a single scratch point or a line segment.

Constructors

ScratchPoint(Offset offset, {bool isNewPath = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isNewPath bool
Whether this point starts a new line segment.
final
offset Offset
The position of the point.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited